@@ -28,12 +28,16 @@ else
     fi
     #check if irexec is needed, and start if need be
     if [ -x /usr/bin/irexec ] && [ ! -f ~/.noirexec ] && [ -f ~/.lircrc ]; then
-        if [ -n "$(cat ~/.lircrc | grep --invert-match "#" | grep irexec | grep prog)" ]
+        if [ -n "$(cat ~/.lirc/* | grep --invert-match "#" | grep irexec | grep prog)" ]
         then
             killall irexec
             irexec -d
         fi
     fi
+    #x11vnc
+    if [ -x /usr/bin/x11vnc ] && [ -f /root/.vnc/passwd ]; then
+        x11vnc -rfbauth /root/.vnc/passwd -rfbport 5900 -shared -forever -nowf -norc -notruecolor -bg
+    fi
     #Customized home commands
     if [ -x $HOME/.mythtv/session ]; then
         $HOME/.mythtv/session &
